@@ -1,5 +1,8 @@
 from .task import BaseTask
 
+DEFAULT_RETRIES = 5
+DEFAULT_ACK_TIMEOUT = 1
+
 
 class AbstractQueue:
 
@@ -24,7 +27,7 @@ class AbstractQueue:
     def subscribe(self):
         raise NotImplementedError("abstract queue")
 
-    def get_message(self, **kwrds):
+    def list_active_channels(self):
         raise NotImplementedError("abstract queue")
 
     @property
